/***************************************************/
/* Game Excelleration Kit vX                       */
/* Copyright (C) 2001 by HourGlass Software NonInc */
/***************************************************/
#ifndef __GEK_Math__
#define __GEK_Math__
/*! 
	\author MoJo
    \file GEKXMath.h
    \brief GEKvX Math Main Header
*/

/*! 
	\mainpage GEKvX Math Library
	\section disclamer Disclamer
		Game Excelleration Kit vX

		<center><img src="..\..\hourglass.jpg" alt="HourGlass SoftWare"></center>
		Copyright (C) 2001 by HourGlass Software NonInc

		This program is free software; you can redistribute it and/or modify
		it under the terms of the GNU General Public License as published by
		the Free Software Foundation; either version 2 of the License, or
		(at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program; if not, write to the Free Software
		Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

		Please read the file LICENSE.TXT for additional details.

		<a href="http://www.doxygen.org>Doxygen</a> was used for all documentation.
*/

#define _PI							3.14159265358979323846f		//!< Extended floating point definition of PI
#define _2_PI						6.28318530717958623200f		//!< Extended floating point definition of (PI * 2)
#define _PI_2						1.57079632679489661923f		//!< Extended floating point definition of (PI / 2)
#define _INV_PI						0.31830988618379069122f		//!< Extended floating point definition of Inverse PI
#define _DEGTORAD(x)				(x * (_PI / 180.0f))		//!< Macro to convert degrees to radians
#define _RADTODEG(x)				(x * (180.0f / _PI))		//!< Macro to convert radians to degrees
#define _EPSILON					1.0e-5f						//!< Small offset to account for floating point error

int __fastcall F2ID(float fValue);		//!< Rounds a value down and returns the integer
int __fastcall F2IU(float fValue);		//!< Rounds a value up and returns the integer
float __fastcall ABS(float fValue);		//!< Returns the absolute value of a value
float __fastcall SIN(float fValue);		//!< Returns the sin of a value
float __fastcall COS(float fValue);		//!< Returns the cos of a value
float TAN(float fValue);				//!< Returns the tangent of a value
float SQRT(float fValue);				//!< Returns the square root of a value
float __fastcall ISQRT(float fValue);	//!< Returns the inverse square root of a value
int NextSquare(int iValue);				//!< Returns the next possible squared value

template <typename CLASS>
inline void SWAP(CLASS &kValueA, CLASS &kValueB)
{
	CLASS kTemp = kValueA;
	kValueA = kValueB;
	kValueB = kTemp;
}

struct GEKVECTOR2;				//!< 2D Vector Class
struct GEKVECTOR3;				//!< 3D Vector Class
struct GEKVECTOR4;				//!< 4D Vector Class
struct GEKQUATERNION;			//!< 4D Quaternion Class
struct GEKMATRIX;				//!< 4x4 Matrix Class
struct GEKPLANE;				//!< Standard Plane Equation
typedef GEKVECTOR4 GEKCOLOR;	//!< RGBA Color Class
struct GEKSPHERE;				//!< Basic Bounding Sphere
struct GEKAABB;					//!< Basic Axis Aligned Bounding Box
struct GEKRAY;					//!< Basic Ray class

#include ".\Include\GEKRect.h"
#include ".\Include\GEKVector2.h"
#include ".\Include\GEKVector3.h"
#include ".\Include\GEKVector4.h"
#include ".\Include\GEKQuaternion.h"
#include ".\Include\GEKMatrix.h"
#include ".\Include\GEKPlane.h"

#include ".\Include\GEKCurve.h"
#include ".\Include\GEKContain.h"
#include ".\Include\GEKFrustum.h"

#include ".\Inline\GEKRect.inl"
#include ".\Inline\GEKVector2.inl"
#include ".\Inline\GEKVector3.inl"
#include ".\Inline\GEKVector4.inl"
#include ".\Inline\GEKQuaternion.inl"
#include ".\Inline\GEKMatrix.inl"
#include ".\Inline\GEKPlane.inl"

#endif
