inline GEKVECTOR2 operator - (const GEKVECTOR2 &kVector)
{
	return GEKVECTOR2(-kVector.x,
					  -kVector.y);
}

inline GEKVECTOR2 operator - (GEKVECTOR2 &kVector)
{
	return GEKVECTOR2(-kVector.x,
					  -kVector.y);
}

inline GEKVECTOR2::GEKVECTOR2(void)
{
	x = y = 0.0f;
}

inline GEKVECTOR2::GEKVECTOR2(const GEKVECTOR2 &kVector)
{
	x = kVector.x;
	y = kVector.y;
}

inline GEKVECTOR2::GEKVECTOR2(const GEKVECTOR3 &kVector)
{
	x = kVector.x;
	y = kVector.y;
}

inline GEKVECTOR2::GEKVECTOR2(const GEKVECTOR4 &kVector)
{
	x = kVector.x;
	y = kVector.y;
}

inline GEKVECTOR2::GEKVECTOR2(float fX, float fY)
{
	x = fX;
	y = fY;
}

inline float &GEKVECTOR2::operator [] (int iAxis)
{
	return xy[iAxis];
}

inline bool GEKVECTOR2::operator < (const GEKVECTOR2 &kVector) const
{
	if((x < kVector.x)&&
	   (y < kVector.y)) return true;
	return false;
}

inline bool GEKVECTOR2::operator > (const GEKVECTOR2 &kVector) const
{
	if((x > kVector.x)&&
	   (y > kVector.y)) return true;
	return false;
}

inline GEKVECTOR2::operator float * (void)
{
	return &x;
}

inline GEKVECTOR2::operator const float * (void) const
{
	return &x;
}

inline GEKVECTOR2::operator -= (const GEKVECTOR2 &kVector)
{
	x -= kVector.x;
	y -= kVector.y;
}

inline GEKVECTOR2::operator += (const GEKVECTOR2 &kVector)
{
	x += kVector.x;
	y += kVector.y;
}

inline GEKVECTOR2::operator /= (float fScalar)
{
	x /= fScalar;
	y /= fScalar;
}

inline GEKVECTOR2::operator *= (float fScalar)
{
	x *= fScalar;
	y *= fScalar;
}

inline GEKVECTOR2 GEKVECTOR2::operator = (const GEKVECTOR2 &kVector)
{
	x = kVector.x;
	y = kVector.y;
	return *this;
}

inline GEKVECTOR2 GEKVECTOR2::operator = (const GEKVECTOR3 &kVector)
{
	x = kVector.x;
	y = kVector.y;
	return *this;
}

inline GEKVECTOR2 GEKVECTOR2::operator = (const GEKVECTOR4 &kVector)
{
	x = kVector.x;
	y = kVector.y;
	return *this;
}

inline GEKVECTOR2 GEKVECTOR2::operator - (const GEKVECTOR2 &kVector) const
{
	return GEKVECTOR2((x - kVector.x),
					  (y - kVector.y));
}

inline GEKVECTOR2 GEKVECTOR2::operator + (const GEKVECTOR2 &kVector) const
{
	return GEKVECTOR2((x + kVector.x),
					  (y + kVector.y));
}

inline GEKVECTOR2 GEKVECTOR2::operator - (const GEKVECTOR2 &kVector)
{
	return GEKVECTOR2((x - kVector.x),
					  (y - kVector.y));
}

inline GEKVECTOR2 GEKVECTOR2::operator + (const GEKVECTOR2 &kVector)
{
	return GEKVECTOR2((x + kVector.x),
					  (y + kVector.y));
}

inline GEKVECTOR2 GEKVECTOR2::operator / (float fScalar) const
{
	return GEKVECTOR2((x / fScalar),
				  	  (y / fScalar));
}

inline GEKVECTOR2 GEKVECTOR2::operator * (float fScalar) const
{
	return GEKVECTOR2((x * fScalar),
					  (y * fScalar));
}

inline GEKVECTOR2 GEKVECTOR2::operator / (float fScalar)
{
	return GEKVECTOR2((x / fScalar),
				  	  (y / fScalar));
}

inline GEKVECTOR2 GEKVECTOR2::operator * (float fScalar)
{
	return GEKVECTOR2((x * fScalar),
					  (y * fScalar));
}

inline float GEKVECTOR2::Dot(const GEKVECTOR2 &kVector) const
{
	return ((x * kVector.x) +
			(y * kVector.y));
}

inline float GEKVECTOR2::Dot(const GEKVECTOR2 &kVector)
{
	return ((x * kVector.x) +
			(y * kVector.y));
}

inline float GEKVECTOR2::GetLengthSqr(void) const
{
	return Dot(*this);
}

inline float GEKVECTOR2::GetLengthSqr(void)
{
	return Dot(*this);
}

inline float GEKVECTOR2::GetLength(void) const
{
	return SQRT(GetLengthSqr());
}

inline float GEKVECTOR2::GetLength(void)
{
	return SQRT(GetLengthSqr());
}

inline void GEKVECTOR2::SetLength(float fLength)
{
	*this *= (fLength / GetLength());
}

inline float GEKVECTOR2::GetAngle(const GEKVECTOR2 &kVector)
{
	float fDot = Dot(kVector);
	float fMagnitude = (GetLength() * kVector.GetLength());
	return acosf(fDot / fMagnitude);
}

inline float GEKVECTOR2::Distance(const GEKVECTOR2 &kVector) const
{
	return (kVector - *this).GetLength();
}

inline float GEKVECTOR2::Distance(const GEKVECTOR2 &kVector)
{
	return (kVector - *this).GetLength();
}

inline GEKVECTOR2 GEKVECTOR2::Lerp(const GEKVECTOR2 &kVector, float fFactor) const
{
	return (*this + ((kVector - *this) * fFactor));
}

inline GEKVECTOR2 GEKVECTOR2::Lerp(const GEKVECTOR2 &kVector, float fFactor)
{
	return (*this + ((kVector - *this) * fFactor));
}

inline GEKVECTOR2 GEKVECTOR2::Normal(void) const
{
	float fLength = GetLength();
	return (*this * (1.0f / fLength));
}

inline GEKVECTOR2 GEKVECTOR2::Normal(void)
{
	float fLength = GetLength();
	return (*this * (1.0f / fLength));
}

inline void GEKVECTOR2::Normalize(void)
{
	*this = Normal();
}